/*
 * Copyright (c) 2016 Razeware LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

'use strict';

import React from 'react';
import ReactNative, {
  StyleSheet,
  Text,
  View,
  NativeModules,
  NativeEventEmitter,
  LayoutAnimation,
} from 'react-native';
const { AddRatingManager } = NativeModules;

const styles = StyleSheet.create({
  container: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: 'gray',
  },
  message: {
    fontSize: 20,
    color: 'white',
  },
});

class ConfirmApp extends React.Component {
  constructor(props) {
    super(props);
    this._subscription = null;
    this.state = {
      show: false,
    }
    // Timer for canceling timer
    this._visibleTimer = null;
    this._setVisible = this._setVisible.bind(this);
  }

  componentDidMount() {
    const AddRatingManagerEvent = new NativeEventEmitter(AddRatingManager);
    this._subscription = AddRatingManagerEvent.addListener(
      'AddRatingManagerEvent',
      (info) => {
        // Look for the save event notification
        if (info.name === 'saveRating') {
          // Show the view
          this._setVisible(true);
          // Hide the view after some time
          this._visibleTimer = setTimeout(() => { this._setVisible(false); }, 2500);
        }
      }
    );
  }

  componentWillUnmount() {
    // Remove event listener
    this._subscription.remove();
    // Clear out timer
    clearTimeout(this._visibleTimer);
  }

  componentWillUpdate() {
    // A little animation so the view fades out when hidden
    LayoutAnimation.linear();
  }

  _setVisible(show) {
    this.setState({ show: show });
  }

  render() {
    // Show or hide the view
    var renderedView = this.state.show ? 
      <View style={styles.container}>
        <Text style={styles.message}>Rating saved successfully.</Text>
      </View> :
      null;

    return renderedView;
  }
}

module.exports = ConfirmApp;